@@ -5,9 +5,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2025-10-15'; # DATE
+our $DATE = '2025-10-16'; # DATE
 our $DIST = 'App-ClipboardUtils'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 use Clipboard::Any ();
 use Clone::PP qw(clone);
@@ -90,9 +90,9 @@ Note that when you use this option, the `--content` argument is ignored. Input
 is taken from stdin. With `--tee`, each output will be printed to stdout. After
 eof, the utility will return empty result.
 
-An example for using this option:
+An example for using this option (<prog:safer> is a utility from <pm:App::safer>):
 
-    % clipadd -c safer
+    % clipadd -c safer --tee
     Foo Bar, Co., Ltd.
     foo-bar-co-ltd
     BaZZ, Co., Ltd.
@@ -230,7 +230,7 @@ App::ClipboardUtils - CLI utilities related to clipboard
 
 =head1 VERSION
 
-This document describes version 0.012 of App::ClipboardUtils (from Perl distribution App-ClipboardUtils), released on 2025-10-15.
+This document describes version 0.013 of App::ClipboardUtils (from Perl distribution App-ClipboardUtils), released on 2025-10-16.
 
 =head1 DESCRIPTION
 
@@ -306,9 +306,9 @@ Note that when you use this option, the C<--content> argument is ignored. Input
 is taken from stdin. With C<--tee>, each output will be printed to stdout. After
 eof, the utility will return empty result.
 
-An example for using this option:
+An example for using this option (L<safer> is a utility from L<App::safer>):
 
- % clipadd -c safer
+ % clipadd -c safer --tee
  Foo Bar, Co., Ltd.
  foo-bar-co-ltd
  BaZZ, Co., Ltd.
